@@ -81,6 +81,8 @@ class Mysql(object):
     def convert_key_value_str(cls, **kwargs) -> tuple:
         field_list, value_list = list(), list()
         for key, value in kwargs.items():
+            if value is None:
+                value = ''
             field_list.append("`{}`".format(key))
             if isinstance(value, str):
                 value = "'{}'".format(value)
